@@ -1,6 +1,6 @@
 import click
 import os
-from .functions_tex import extract_tex_env
+from .functions_tex import extract_tex_env, files
 
 
 tikz_render=r"""
@@ -53,14 +53,10 @@ def main(inputfile, outputfile, environment):
     
     try:
         extract_tex_env(inputfile, outputfile, environment)
-        try:
-            global files
-            files = [f for f in os.listdir(f'{path_tikz}/tikz') if os.path.isfile(f)]
-        except:
-            click.echo("Faild to list files.")
     except:
         click.echo("Failed to extract_tex_env")
 
+    files = [os.path.basename(f) for f in files]
     with open(path_main, 'w') as file:
         file.write(f'\\documentclass{{article}}\n')
         file.write(f'\\usepackage{{v-equation}}\n')
@@ -75,7 +71,7 @@ def main(inputfile, outputfile, environment):
             file.write(f'{tikz_render.replace("tikz.tex", files[0])}\n')
             file.write(f'{tikz_code.replace("tikz.tex", files[0])}\n')
         else:
-            for f in files[1:-1]:
+            for f in files[1:]:
                 file.write(f'{tikz_render.replace("tikz.tex", f)}\n')
                 file.write(f'{tikz_code.replace("tikz.tex", f)}\n')
                 if f != files[-1]:
